#!/usr/bin/wish
#----------------------------------------------------------------------------
# bash.tcl : tcl interface to bash
#	- makes it easier to run repeated, long command lines with 
#	  slightly varying arguments
# author: Yoonsuck Choe <yschoe@cs.utexas.edu>
#----------------------------------------------------------------------------
global gl;

set gl(TMP) "/u/yschoe/tmp";
set gl(current) 0
set gl(search) 0
set gl(max) 0

#--------------------
# Run command: run shell command and show output  of command
#--------------------
proc run_command { } {

  global gl;

  # Get command and strip newline
  set command [.shell get 1.0 end]; 
  regsub "\n" $command " " expression

  set gl(history-$gl(current)) $expression;
  set gl(max) $gl(current)
  set gl(search) $gl(current)
  incr gl(current)
  

  # Execute and get output and update the output window
  set cp [open "$gl(TMP)/tclplot.cmd" "w"]
  puts $cp $expression
  close $cp
  set pp [open "|sh $gl(TMP)/tclplot.cmd &" "r"]
  set gl(output) [read $pp];
  close $pp; 
  .output delete 0.0 end;
  .output insert 0.0 $gl(output);

  # Get rid of newlines in the command window
  .shell delete 0.0 end;
  .shell insert 0.0 $expression;

}

#----------------------------------------------------------------------------
#	Application window
#----------------------------------------------------------------------------

#--------------------
# Text input area : shell command
#--------------------
label .shelltitle -text {Enter shell command and press [Run] or press [Enter]} -justify left
pack .shelltitle -side top
text .shell -width 80 -height 5 -borderwidth 5;
pack .shell -side top -padx 5 -pady 5
bind .shell <Return> {run_command}

# Command History navigation
bind .shell <KeyPress-Up> { 
	set prev [expr $gl(search) -1]
	if {$prev<0} { set prev 0 }
	.shell delete 0.0 end;
	.shell insert 0.0 $gl(history-$prev);
	set gl(search) $prev
}
bind .shell <KeyPress-Down> { 
	set next [expr $gl(search) +1]
	if {$next>$gl(max)} { set next $gl(max) }
	.shell delete 0.0 end;
	.shell insert 0.0 $gl(history-$next);
	set gl(search) $next
}
# Clear with Control_L
bind .shell <Control-Key-l> {
	.shell delete 0.0 end;
}
wm resizable . 0 0

#--------------------
# Buttons
#--------------------
frame .bf 
pack .bf -side top
button .bf.go -text "Run" -command { run_command; }
pack .bf.go -side left
button .bf.clear -text "Clear" -command { .shell delete 0.0 end; }
pack .bf.clear -side left
button .bf.quit -text "Quit" -command exit
pack .bf.quit -padx 5 -pady 5

#--------------------
# Output window
#--------------------
text .output -width 80 -height 15 -borderwidth 5;
pack .output -side top -padx 5 -pady 5

#----------------------------------------------------------------------------
# main : nothing's done here yet
#----------------------------------------------------------------------------
wm geometry . +0+0

