#!/usr/bin/wish

# Configurable area
# set filename "gray.ppm"
# set width 1024
# set height 193
# set input_spec "b:i:b:i:b:i:b"
# set input_tick_spec "0:100:200:300:400:500:600:700"
# set conn_spec "g:b:g:b:g:b"
# set conn_tick_spec "0:100:200:300:400:500:600"
# set scale_spec "1:100:500"

set filename 	[lindex $argv 0]
set iwidth    	[lindex $argv 1]
set iheight	[lindex $argv 2]
set input_spec  [lindex $argv 3]
set input_tick_spec  [lindex $argv 4]
set scale_spec  [lindex $argv 5]

set offset_flag 0

# derived values 
set zoomx	1
# set fontsize    9 ; set mult 2 ; set width 300; set zoomy	2
set fontsize    11 ; set mult 1.0 ; set width 500; set zoomy 3
set height	[expr int($iheight * $zoomy)]

puts stderr "zoom : x=$zoomx, y=$zoomy"

# set fontsize [expr int(16 * $width/1000)]
# if { $fontsize < 12 } { set fontsize 12 }
set smfontsize 16
set tinyfontsize 14
font create myfont -family Helvetica -size $fontsize
font create mysmfont -family Helvetica -size $smfontsize
font create mytinyfont -family Helvetica -size $tinyfontsize
set font "myfont"
set smfont "mysmfont"
set tinyfont "mytinyfont"
set bararearatio 0.04
set barareawidth [expr $bararearatio * $width]
set scaleheight  [expr $bararearatio * $width / 3 * $mult]
set plotwidth [expr $width + 1.5*$barareawidth]
set plotheight [expr $height + 3.5*$scaleheight]
set barwidth [expr $barareawidth/3]

#----------------------------------------
# First load the image to be annotated
#----------------------------------------
image create photo MUAsmall -file $filename -width $iwidth -height $iheight
image create photo MUA -file $filename -width $width -height $height
MUA copy MUAsmall -from 0 0 $width $iheight -zoom $zoomx $zoomy
puts "Width = $width, Height = $height"

#----------------------------------------
# Create canvas
#----------------------------------------
canvas .plot -width $plotwidth -height $plotheight -background white

set xoffset [expr $barareawidth*0.75]
set yoffset [expr $scaleheight*1.5]

pack .plot -side top -padx 10 -pady 10

#----------------------------------------
# Create buttons
#----------------------------------------
button .psdump -command { \
        .plot postscript -file genfig.ps ; \
        } -text "PS Dump"
pack .psdump -side top;

button .quit -command { exit } -text "Quit"
pack .quit -side top -padx 10 -pady 10

#----------------------------------------
# Add image to canvas
#----------------------------------------
.plot create image $xoffset $yoffset -image MUA -anchor nw
# draw border
.plot create rectangle $xoffset $yoffset \
		[expr $xoffset+$width] [expr $height+$yoffset] -outline black


#----------------------------------------
# Add input spec to the canvas
#----------------------------------------

# Parse input spec string
set inputs [split $input_spec ":"]
set ticks   [split $input_tick_spec ":"]
set numinp [llength $inputs]

# .plot create rectangle [expr $barwidth] [expr $yoffset]\
#	[expr $barwidth*2] \
#	[expr $yoffset + $height] -outline black

for {set i 0} {$i<=$numinp} {incr i} {

	set offset [expr ($barwidth*0.5 -($i%2)*$barwidth/1.2)*$offset_flag]

	set ygran [expr $height/$numinp]

	puts stderr $offset 

	if { $i == $numinp } {
		set ycorner [expr $height - ($i + 1) * $height/$numinp + $yoffset]
		set ybegin [expr $yoffset - $ygran/2.0]
	} else {
		set ycorner [expr $height - ($i + 1) * $height/$numinp + $yoffset]
		set ybegin [expr $height - $i * $height/$numinp + $yoffset + 1 - $ygran/2.0]
	}

	
	if { $i == $numinp } {	# only plot text
		.plot create text [expr $barwidth*0.5+$offset] $ybegin \
			-text [lindex $ticks [expr $i]] -anchor center -font $font
		break;
	}

	.plot create text [expr $barwidth*0.5+$offset] $ybegin \
		-text [lindex $ticks [expr $i]] -anchor center -font $font 
}

puts stderr "numinp = $numinp"


# .plot create text [expr $width+$barwidth*5.5] [expr $yoffset*3 + $height] -text $connstr -font $smfont  -anchor w

#----------------------------------------
# Add scale to bottom of the canvas
#----------------------------------------

set onescaleheight [expr $scaleheight/4]
set scale_param [split $scale_spec ":"]
set begin [lindex $scale_param 0]
set steps [lindex $scale_param 1]
set end [lindex $scale_param 2]
set endidx [expr $end/$steps]
set gran [expr $width/(($end-$begin+1)/$steps)]
puts stderr "$begin $steps $end"

puts "Gran = $gran"

.plot create line \
	$xoffset [expr $height+$onescaleheight*2 + $yoffset ] \
	[expr $xoffset + $width] [expr $height+$onescaleheight*2 + $yoffset]  \
	-fill black -width 1

set ticktop [expr $height+$onescaleheight*2 + $yoffset ]
set tickbottom [expr $height+$onescaleheight*4 + $yoffset ]
set scalepos [expr $height+$onescaleheight*7 + $yoffset ]

for {set i 0} {$i<=$endidx} {incr i} {

	if {$i == $endidx} {
		set xcorner [expr $xoffset + $width]
	} else {
		set xcorner  [expr $xoffset + $gran*$i]
	}
	
	.plot create line \
		$xcorner $ticktop \
		$xcorner $tickbottom \
		-fill black -width 1
	.plot create text \
		$xcorner $scalepos \
		-text [expr $i * $steps] -font $font
} 

update;

.plot postscript -file genfig.ps;

exit;
