#!/usr/bin/perl

$usage = <<EOF;
usage: genmuaspec-tune.pl [-f <size>] [-y <displ>] [-n] [-o <order>] [-t num,x,y:...] <conffile> [<ppmfile>]
	-n  : no text label
EOF


if ($#ARGV<0) {
 	print $usage;
	exit;
}

if ($ARGV[0] eq "-f") {
	shift;
	$fsize = $ARGV[0];
	shift;
} else {
	$fsize = 50;
}

if ($ARGV[0] eq "-y") {
	shift;
	$ydispl = $ARGV[0];
	shift;
} else {
	$ydispl = 0.9;
}

if ($ARGV[0] eq "-n") {
	shift;
	$notext = 1;
} else {
	$notext = 0;
}


if ($ARGV[0] eq "-o") {
	shift;
	@order = split(/:/,$ARGV[0]);
	$order_flag = 1;
	shift;
} else {
	$order_flag = 0;
}

if ($ARGV[0] eq "-t") {
	shift;
	@adjust_array = split(/:/,$ARGV[0]);
	foreach $adjstr (@adjust_array) {
		($num,$x,$y) = split(/,/,$adjstr);
		$adj_x{$num} =$x;
		$adj_y{$num} =$y;
  	}	
	$adjust_flag = 1;
	shift;
} else {
	$adjust_flag = 0;
}

open (FP,"$ARGV[0]");

$k=0;
while (<FP>) {

	if (/set N2 = ([0-9]+)/) {
		$n = $1;
		print STDERR "N = $n\n";
	}

	if (/call_add_mua_spec_circle2[\s]+([0-9]+)[\s]+([0-9]+)[\s]+([0-9\.]+)/) {
		$x[$k] = $1;		
		$y[$k] = $2;		
		$r[$k] = $3;		
		$k++;
	}
}
close(FP);

if ($#ARGV==0) {
	$ppm = "noppm";
	print STDERR "ppm = $ppm\n";
} else {
	$ppm = $ARGV[1];
	print STDERR "ppm = $ppm\n";
}
	
$str = "annoteppm.tcl $n 10 $ppm ";
for ($i=0; $i<$k; ++$i) {
	if ($order_flag) {
		$idx = $order[$i]-1;
		print "$i : order = ".($idx+1)."\n";
	} else {	
		$idx = $i;
	}
	$str .= "circ,".($x[$i]).",".($y[$i]).",".(int($r[$i])).",black:";

	if ($x[$i]<($r[$i]*0.7)) { # left border
		$txt_x = int(($x[$i]+$r[$i]*cos(45/180*3.141592))/2.0);
		$txt_y = $y[$i]-$ydispl;
	} elsif (($n-$x[$i])<$r[$i]*0.7) { # right border
		$txt_x = $n-int(($n-$x[$i]+$r[$i]*cos(45/180*3.141592))/2.0)-0.5;
		$txt_y = $y[$i]-$ydispl;
	} elsif ($y[$i]<$r[$i]*0.7) { # top border
		$txt_x = $x[$i];
		$txt_y = int(($y[$i]+$r[$i]*cos(34/180*3.141592))/2.0)-$ydispl;
	} elsif (($n-$y[$i])<$r[$i]*0.7) { # bottom border
		$txt_x = $x[$i];
		$txt_y = $n-int(($n-$y[$i]+$r[$i]*cos(34/180*3.141592))/2.0)-0.5-$ydispl;
	} else {
		$txt_x = $x[$i];
		$txt_y = $y[$i]-$ydispl;
	}

	# individually adjust x,y location
	$id = $idx+1;
	if (exists($adj_x{$id})) {
		$xoffset = $adj_x{$id};
		$yoffset = $adj_y{$id};
	} else {
		$xoffset = 0.0;
		$yoofset = 0.0;
	}

	if (!$notext) {
	$str .= "text,".($txt_x+$xoffset).",".($txt_y+$yoffset).",".($idx+1).",$fsize,black:";
	}
}

chop $str;

system($str);

$basename = `basename $ARGV[0] .conf`;
chop $basename;

if ($#ARGV==0) {
	$fname = "mv noppm-annoted.ps $basename".".spec.ps";
}

system ($fname);
`epstopdf $basename.spec.ps`;
`acroread $basename.spec.pdf`;

