#!/usr/bin/perl

$usage = <<EOF;

usage: mkhtmlslide.pl <x-size> <y-size> <image files>

	<x-size>	: width of image in number of pixels
	<y-size>	: height of image in number of pixels
	<image files>	: a list of one or more images (in any browser
			  compatible format)

	generates a series of html files with
	each image in the list as image maps where
	clicking on the left half would go back, while 
	clicking on the right half would go forward in the list.

EOF

#----------------------------------------
# 1. Process Arguments : get x, y pixel width of the 
#----------------------------------------
if ($#ARGV<2) {
	print $usage;
	exit;
}

$x = shift(@ARGV);
$y = shift(@ARGV);

print "x = $x, y = $y\n";

#----------------------------------------
# 2. Generate web pages
#----------------------------------------

for ($i=0; $i<=$#ARGV; ++$i) {
	
	# if next page index exceeds the end of list, wrap around to first page
	$prev_img_idx = ($i-1<0)?$#ARGV:($i-1);
	$next_img_idx = ($i+1>$#ARGV)?0:($i+1);
	
	# generate web page with current and next image filename as index
	print "generating page for : $ARGV[$i] \n";
	&generate_page($prev_img_idx,$i,$next_img_idx,
		       $ARGV[$prev_img_idx],$ARGV[$i],$ARGV[$next_img_idx],
		       $x,$y);

}

#----------------------------------------
# 3. Generate index and list page
#----------------------------------------
&make_index();

&make_list($#ARGV);

#----------------------------------------------------------------------------
# Subroutine
#----------------------------------------------------------------------------

#----------------------------------------
# 	generate slide pages
#----------------------------------------
sub generate_page {

  # fetch arguments
  my ($prev,$cur,$next,$prev_img,$cur_img,$next_img,$x,$y) = @_;

  my $half_x = $x/2;

  $cur = sprintf("%03d",$cur);
  $next = sprintf("%03d",$next);
  $prev = sprintf("%03d",$prev);

  # generate slide file

  open(FP,">slide$cur.html");

  print FP <<EOF;
<html>
<head>
	<style type="text/css">
	BODY {overflow: scroll; overflow-x: hidden;}
	</style>
	<title>Slide $cur</title>
</head>

<body bgcolor=white>
EOF

  print FP <<'EOF';

<script language="JavaScript1.2">
<!--

/*
Submitted by Marcin Wojtowicz [one_spook@hotmail.com] 
Featured on Website Abstraction (http://wsabstract.com)
For this and over 400+ free scripts, visit http://wsabstract.com
*/

var trailLength = 1 // The length of trail (8 by default; put more for longer "tail")
var path = "cursor.gif" // URL of your image

// do NOT modify anything beyond this point
var isIE = false,isNav = false,range = "all.",style = ".style",i,d = 0
var topPix = ".pixelTop",leftPix = ".pixelLeft",images,storage
if (document.layers) { // browser sniffer
	isNav = true,range = "layers.",style = "",topPix = ".top",leftPix = ".left"
} else if (document.all) {
	isIE = true
}
function initTrail() { // prepares the script
	images = new Array() // prepare the image array
	for (i = 0; i < parseInt(trailLength); i++) {
		images[i] = new Image()
		images[i].src = path
	}
	storage = new Array() // prepare the storage for the coordinates
	for (i = 0; i < images.length*3; i++) {
		storage[i] = 0
	}
	for (i = 0; i < images.length; i++) { // make divs for IE and layers for Navigator
		(isIE) ? document.write('<div id="obj' + i + '" style="position: absolute; z-Index: 100; height: 0; width: 0"><img src="' + images[i].src + '"></div>') : document.write('<layer name="obj' + i + '" width="0" height="0" z-index="100"><img src="' + images[i].src + '"></layer>')
	}
	trail()
}
function trail() { // trailing function
	for (i = 0; i < images.length; i++) { // for every div/layer
		eval("document." + range + "obj" + i + style + topPix + "=" + storage[d]) // the Y-coordinate
		eval("document." + range + "obj" + i + style + leftPix + "=" + storage[d+1]) // the X-coordinate
		d = d+2
	}
	for (i = storage.length; i >= 2; i--) { // save the coordinate for the div/layer that's behind
		storage[i] = storage[i-2]
	}
	d = 0 // reset for future use
	var timer = setTimeout("trail()",10) // call recursively 
}
function processEvent(e) { // catches and processes the mousemove event 
	if (isIE) { // for IE
		storage[0] = window.event.y+document.body.scrollTop+10
		storage[1] = window.event.x+document.body.scrollLeft+10
	} else { // for Navigator
		storage[0] = e.pageY-13
		storage[1] = e.pageX-12
	}
}
if (isNav) {
	document.captureEvents(Event.MOUSEMOVE) // Defines what events to capture for Navigator
}
if (isIE || isNav) { // initiates the script
	initTrail() 
	document.onmousemove = processEvent // start capturing
}
//-->
</script>
EOF

  print FP <<EOF;

<img src="$cur_img" border=0 usemap="#navigate" width=$x height=$y>

<map name="navigate">
  <area shape="rect" coords="0,0,$half_x,149" href="list.html">
  <area shape="rect" coords="$half_x,0,$x,149" href="util-index.html">
  <area shape="rect" coords="0,150,$half_x,$y" href="slide$prev.html">
  <area shape="rect" coords="$half_x,150,$x,$y" href="slide$next.html">
</map>
<br>
<font color="gray">Slide $cur</font>
EOF

  close(FP);

}
 
#----------------------------------------
# 	make index.html
#----------------------------------------
sub make_index {

  my $newx = $x+50;
  my $newy = $y+150;
  open(FP,">index.html");
  print FP <<EOF;
<html>
<head>
	<title> Talk </title>
<SCRIPT LANGUAGE="JavaScript1.2"> 
msgWindow=window.open("slide000.html",
	"displayWindow",
	"status=yes,width=$newx,height=$newy")
</SCRIPT>
</head>
<body bgcolor=white>
	<h1 align=center>Yoonsuck Choe</h1>
</body>
EOF
  close(FP);

}

#----------------------------------------
# 	generate list pages
#----------------------------------------
sub make_list {

  open(FP,"hrefize slide*.html |");
  my @lines = <FP>;
  my $str = join("",@lines);
  close(FP);

  open(FP,">list.html");
  print FP <<EOF;
<html>
<head>
	<title> Slide List </title>
<body bgcolor=white>
	<h1 align=center>Slide List</h1>
	<p>
	<ul>
	$str	
	</ul>
</body>
EOF
  close(FP);

}

